@@ -4,7 +4,7 @@
 #include "config.h"
 
 void
-gravatar_tooltip(Evas_Object *obj, Config *config, char *email);
+gravatar_tooltip(Evas_Object *obj, const Config *config, char *email);
 
 void gravatar_init(void);
 void gravatar_shutdown(void);
